@@ -1,6 +1,9 @@
+"""
+google translator API
+"""
 
 from deep_translator.constants import BASE_URLS, GOOGLE_LANGUAGES_TO_CODES
-from deep_translator.exceptions import LanguageNotSupportedException, TranslationNotFound, NotValidPayload
+from deep_translator.exceptions import LanguageNotSupportedException, TranslationNotFound, NotValidPayload, RequestError
 from deep_translator.parent import BaseTranslator
 from bs4 import BeautifulSoup
 import requests
@@ -8,7 +11,7 @@ import requests
 
 class GoogleTranslator(BaseTranslator):
     """
-    class that uses google translate to translate texts
+    class that wraps functions, which use google translate under the hood to translate text(s)
     """
     _languages = GOOGLE_LANGUAGES_TO_CODES
     supported_languages = list(_languages.keys())
@@ -34,32 +37,42 @@ class GoogleTranslator(BaseTranslator):
 
     @staticmethod
     def get_supported_languages(as_dict=False):
+        """
+        return the supported languages by the google translator
+        @param as_dict: if True, the languages will be returned as a dictionary mapping languages to their abbreviations
+        @return: list or dict
+        """
         return GoogleTranslator.supported_languages if not as_dict else GoogleTranslator._languages
 
     def _map_language_to_code(self, *languages):
         """
-
-        @param language: type of language
+        map language to its corresponding code (abbreviation) if the language was passed by its full name by the user
+        @param languages: list of languages
         @return: mapped value of the language or raise an exception if the language is not supported
         """
         for language in languages:
-            if language in GOOGLE_LANGUAGES_TO_CODES.values() or language == 'auto':
+            if language in self._languages.values() or language == 'auto':
                 yield language
-            elif language in GOOGLE_LANGUAGES_TO_CODES.keys():
-                yield GOOGLE_LANGUAGES_TO_CODES[language]
+            elif language in self._languages.keys():
+                yield self._languages[language]
             else:
                 raise LanguageNotSupportedException(language)
 
     def is_language_supported(self, *languages):
+        """
+        check if the language is supported by the translator
+        @param languages: list of languages
+        @return: bool or raise an Exception
+        """
         for lang in languages:
-            if lang != 'auto' and lang not in GOOGLE_LANGUAGES_TO_CODES.keys():
-                if lang != 'auto' and lang not in GOOGLE_LANGUAGES_TO_CODES.values():
+            if lang != 'auto' and lang not in self._languages.keys():
+                if lang != 'auto' and lang not in self._languages.values():
                     raise LanguageNotSupportedException(lang)
         return True
 
     def translate(self, text, **kwargs):
         """
-        main function that uses google translate to translate a text
+        function that uses google translate to translate a text
         @param text: desired text to translate
         @return: str: translated text
         """
@@ -73,15 +86,25 @@ class GoogleTranslator(BaseTranslator):
             response = requests.get(self.__base_url,
                                     params=self._url_params)
 
+            if response.status_code != 200:
+                raise RequestError()
+
             soup = BeautifulSoup(response.text, 'html.parser')
             element = soup.find(self._element_tag, self._element_query)
+
             if not element:
-                # raise ElementNotFoundInGetRequest(element)
                 raise TranslationNotFound(text)
 
             return element.get_text(strip=True)
 
     def translate_file(self, path, **kwargs):
+        """
+        translate directly from file
+        @param path: path to the target file
+        @type path: str
+        @param kwargs: additional args
+        @return: str
+        """
         try:
             with open(path) as f:
                 text = f.read()
@@ -112,3 +135,8 @@ class GoogleTranslator(BaseTranslator):
 
         except Exception as e:
             raise e
+
+
+if __name__ == '__main__':
+    res = GoogleTranslator("auto", "de").translate("keep it up, you are awesome")
+    print(res)
